package org.bouncycastle.jce.cert;

import java.security.InvalidAlgorithmParameterException;

/**
 *
 * The <i>Service Provider Interface</i> (<b>SPI</b>) 
 * for the {@link CertPathValidator CertPathValidator} class. All 
 *  CertPathValidator</code> implementations must include a class (the
 * SPI class) that extends this class ( CertPathValidatorSpi</code>) 
 * and implements all of its methods. In general, instances of this class 
 * should only be accessed through the  CertPathValidator</code> class. 
 * For details, see the Java Cryptography Architecture.<br />
 * <br />
 * <b>Concurrent Access</b><br />
 * <br />
 * Instances of this class need not be protected against concurrent
 * access from multiple threads. Threads that need to access a single
 *  CertPathValidatorSpi</code> instance concurrently should synchronize
 * amongst themselves and provide the necessary locking before calling the
 * wrapping  CertPathValidator</code> object.<br />
 * <br />
 * However, implementations of  CertPathValidatorSpi</code> may still
 * encounter concurrency issues, since multiple threads each
 * manipulating a different  CertPathValidatorSpi</code> instance need not
 * synchronize.
 **/
public abstract class CertPathValidatorSpi extends Object
{
    /**
     * The default constructor.
     */
    public CertPathValidatorSpi() {}

    /**
     * Validates the specified certification path using the specified 
     * algorithm parameter set.<br />
     * <br />
     * The  CertPath</code> specified must be of a type that is 
     * supported by the validation algorithm, otherwise an 
     *  InvalidAlgorithmParameterException</code> will be thrown. For 
     * example, a  CertPathValidator</code> that implements the PKIX 
     * algorithm validates  CertPath</code> objects of type X.509.
     *
     * @param certPath the  CertPath</code> to be validated
     * @param params the algorithm parameters
     *
     * @return the result of the validation algorithm
     *
     * @exception CertPathValidatorException if the  CertPath</code> 
     * does not validate
     * @exception InvalidAlgorithmParameterException if the specified 
     * parameters or the type of the specified  CertPath</code> are 
     * inappropriate for this  CertPathValidator</code>
     */
    public abstract CertPathValidatorResult engineValidate(CertPath certPath, CertPathParameters params)
    throws CertPathValidatorException,
    InvalidAlgorithmParameterException;
}
